<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ne">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>इमेज विएवेर</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>छवि दर्शक फेशन इन्टरफेस र चिल्लो प्रदर्शनको साथ छवि दृश्य उपकरण हो।</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation type="vanished">छविहरू</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>छवि जानकारी</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="vanished">अल्त +रीतर्न / Alt +Return</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>आधारभूत जानकारी</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>यस फाईलमा बहु पृष्ठहरू छन्, कृपया सबै पृष्ठहरू हेर्न ईभान्स प्रयोग गर्नुहोस्।</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation type="vanished">निर्देशिका खोल्नुहोस्</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>तपाईंसँग तस्वीर हेर्न अनुमति छैन</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation type="vanished">रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">डिलिट गर्नुहोस्  / हटाउनु गर्नुहोस् </translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation type="vanished">तस्वीर फाईल फेला परेन</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>नाम</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>मिति परिमार्जित</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="vanished">आयाम</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>फाईल आकार</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>मिति कब्जा गरियो</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>एक्सपोजर मोड</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>एक्सपोजर प्रोग्राम</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>एक्सपोजर समय</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>फ्ल्यास</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>एपर्चर</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>फोकल लम्बाई</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>अधिकतम एपर्चर</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>मिटरिंग मोड</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>सेतो सन्तुलन</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>फ्ल्यास क्षतिपूर्ति</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>लेन्स मोडेल</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>कलरस्पेस</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>क्यामेरा मोडेल</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>आयाम</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>ट्याग</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="vanished">कुनै स्केलि छैन</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="vanished">छविमा पृष्ठ फिट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="vanished">पृष्ठमा छवि फिट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="vanished">&#xa0;स्केल तु</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation type="vanished">मिलीमीटर</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation type="vanished">सेंटीमीटर</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation type="vanished">ईन्चहरू</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="vanished">छवि स्थिति</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="vanished">स्कलिङ </translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="vanished">छवि सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="vanished">छवि सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="vanished">ब्लाइन्डहरू</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation type="vanished">स्विचर</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="vanished">स्लाइडि</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation type="vanished">रिङ्ग </translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation type="vanished">वर्षा /महिना /गते  घण्टा :मिनट :दिन</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation type="vanished">निर्देशिका चयन गर्नुहोस्</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation type="vanished">यो निर्देशिका सिंक गर्न असक्षम गरिएको छ</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation type="vanished">फोल्डर थप्नुहोस्</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation type="vanished">सिंक निर्देशिका व्यवस्थापन</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation type="vanished">निर्देशिका सूची खाली छ</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation type="vanished">सिंक रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="vanished">छविहरू</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation type="vanished">उपकरण हटाइएको छ</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation type="vanished">यो डाइरेक्टरी अब अवस्थित छैन</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation type="vanished">गणना गर्दै ...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>छवि अवलोकन</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">एल्बम</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">हेर्नुहोस्</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="vanished">अन्त्य कार्यक्रम</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>कपि गर्नुहोस् </translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">एल्बमबाट हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">नमनपर्ने</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबन्धकमा प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>छवि जानकारी</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation type="vanished">अघिल्लो स्क्रिन</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation type="vanished">अर्को स्क्रिन</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="vanished">नयाँ एल्बम</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>नाम बदल्नुहोस्</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>मद्दत</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>सर्टकट प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनु होस् </translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>पूर्णस्क्रीनबाट बाहिर निस्कनुहोस्</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>जुम इन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>जुम आउट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>खोल्नुहोस्</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation type="vanished">कृपया नयाँ सर्टकट प्रविष्ट गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">सर्टकटहरू</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation type="vanished">चित्र हेर्नुहोस्</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">एल्बम</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="vanished">फेरी पहिलाकै अवस्था मा लैजाऊ</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="vanished">हेर्नुहोस्</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">स्लाइड शो</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="vanished">अन्त्य कार्यक्रम</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="vanished">प्रिन्ट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">कपि</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">एल्बमबाट हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">मन नपर्ने</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">फाइल प्रबन्धकमा प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="vanished">छवि जानकारी</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="vanished">नयाँ एल्बम</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">नाम बदल्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">हटाउनु होस् </translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="vanished">स्लाइड सेटिंग्स</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation type="vanished">स्विच प्रभाव</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">अवधि</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="vanished">स्विच अवधि</translation>
    </message>
    <message>
        <source>second</source>
        <translation type="vanished">सेकन्ड</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>मेरो मन पर्ने</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1: 1 आकार</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>विन्डोमा फिट</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनु होस् </translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation type="vanished">पछाडि</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation type="vanished">छवि प्रबन्धन</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>मेरो मन पर्ने</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1: 1 आकार</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>विन्डोमा फिट</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मन नपर्ने</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मन पर्ने</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनु होस् </translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>कुनै छवि फाईलहरू फेला परेनन्</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>छवि खोल्नुहोस्</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>छवि फाईल फेला परेन</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="vanished">स्लाइड सेटिंग्स</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation type="vanished">एफ्फेक्त </translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">अवधि</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">सर्टकटहरू</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">हेर्नुहोस्</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">एल्बम</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation type="vanished">नयाँ एल्बम</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation type="vanished">समय रेखा</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="vanished">एल्बममा थप्नुहोस्</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="vanished">नयाँ एल्बममा थप्नुहोस्</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>पूर्णस्क्रीनबाट बाहिर निस्कनुहोस्</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिन्ट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>कपि </translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">एल्बमबाट हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">मन नपर्ने</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>नेभिगेसन विन्डो देखाउनुहोस्</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>नेभिगेसन विन्डो लुकाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबन्धकमा प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>छवि जानकारी</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनु होस् </translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>छवि खोल्नुहोस्</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>सबै छविहरू</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>नाम बदल्नुहोस्</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
